@@ -28,6 +28,7 @@ from .qt.QtGui import (
     QPainter,
     QPalette,
     QColor,
+    QBrush,
 )
 from .qt.QtCore import Qt, Signal, QEvent, QSize, QRectF
 
@@ -163,18 +164,16 @@ class QwtPlotDict(object):
         """
         self.__data.itemList.removeItem(item)
 
-    def detachItems(self, rtti, autoDelete):
+    def detachItems(self, rtti=None):
         """
         Detach items from the dictionary
         
-        :param int rtti: In case of `QwtPlotItem.Rtti_PlotItem` detach all items otherwise only those items of the type rtti.
-        :param bool autoDelete: If true, delete all detached items
+        :param rtti: In case of `QwtPlotItem.Rtti_PlotItem` or None (default) detach all items otherwise only those items of the type rtti.
+        :type rtti: int or None
         """
         for item in self.__data.itemList[:]:
-            if rtti == QwtPlotItem.Rtti_PlotItem and item.rtti() == rtti:
+            if rtti in (None, QwtPlotItem.Rtti_PlotItem) or item.rtti() == rtti:
                 item.attach(None)
-                if self.autoDelete:
-                    self.__data.itemList.remove(item)
 
     def itemList(self, rtti=None):
         """
@@ -275,8 +274,8 @@ class QwtPlot(QFrame, QwtPlotDict):
 
     """
 
-    itemAttached = Signal("PyQt_PyObject", bool)
-    legendDataChanged = Signal("PyQt_PyObject", "PyQt_PyObject")
+    itemAttached = Signal(object, bool)
+    legendDataChanged = Signal(object, object)
 
     # enum Axis
     AXES = yLeft, yRight, xBottom, xTop = list(range(4))
@@ -1516,7 +1515,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`canvasBackground()`
         """
         pal = self.__data.canvas.palette()
-        pal.setBrush(QPalette.Window, brush)
+        pal.setBrush(QPalette.Window, QBrush(brush))
         self.canvas().setPalette(pal)
 
     def canvasBackground(self):
