@@ -16,8 +16,15 @@ QwtSymbol
 from .graphic import QwtGraphic
 from .painter import QwtPainter
 
-from .qt.QtGui import (QPainter, QTransform, QPixmap, QPen, QPolygonF,
-                          QPainterPath, QBrush)
+from .qt.QtGui import (
+    QPainter,
+    QTransform,
+    QPixmap,
+    QPen,
+    QPolygonF,
+    QPainterPath,
+    QBrush,
+)
 from .qt.QtCore import QSize, QRect, QPointF, QRectF, QSizeF, Qt, QPoint
 from .qt.QtSvg import QSvgRenderer
 
@@ -25,7 +32,7 @@ import numpy as np
 
 
 class QwtTriangle(object):
-    
+
     # enum Type
     Left, Right, Up, Down = list(range(4))
 
@@ -46,12 +53,12 @@ def qwtScaleBoundingRect(graphic, size):
     if scaledSize.isEmpty():
         scaledSize = graphic.defaultSize()
     sz = graphic.controlPointRect().size()
-    sx = 1.
-    if sz.width() > 0.:
-        sx = scaledSize.width()/sz.width()
-    sy = 1.
-    if sz.height() > 0.:
-        sy = scaledSize.height()/sz.height()
+    sx = 1.0
+    if sz.width() > 0.0:
+        sx = scaledSize.width() / sz.width()
+    sy = 1.0
+    if sz.height() > 0.0:
+        sy = scaledSize.height() / sz.height()
     return graphic.scaledBoundingRect(sx, sy)
 
 
@@ -66,14 +73,14 @@ def qwtDrawPixmapSymbols(painter, points, numPoints, symbol):
     pm = QPixmap(symbol.pixmap())
     if pm.size() != size:
         pm = pm.scaled(size)
-    pinPoint = QPointF(.5*size.width(), .5*size.height())
+    pinPoint = QPointF(0.5 * size.width(), 0.5 * size.height())
     if symbol.isPinPointEnabled():
         pinPoint = symbol.pinPoint()
     painter.resetTransform()
     for pos in points:
-        pos = QPointF(transform.map(pos))-pinPoint
-        QwtPainter.drawPixmap(painter, QRect(pos.toPoint(), pm.size(), pm))
-        
+        pos = QPointF(transform.map(pos)) - pinPoint
+        QwtPainter.drawPixmap(painter, QRect(pos.toPoint(), pm.size()), pm)
+
 
 def qwtDrawSvgSymbols(painter, points, numPoints, renderer, symbol):
     if renderer is None or not renderer.isValid():
@@ -84,16 +91,16 @@ def qwtDrawSvgSymbols(painter, points, numPoints, renderer, symbol):
     sz = QSizeF(symbol.size())
     if not sz.isValid():
         sz = viewBox.size()
-    sx = sz.width()/viewBox.width()
-    sy = sz.height()/viewBox.height()
+    sx = sz.width() / viewBox.width()
+    sy = sz.height() / viewBox.height()
     pinPoint = QPointF(viewBox.center())
     if symbol.isPinPointEnabled():
         pinPoint = symbol.pinPoint()
-    dx = sx*(pinPoint.x()-viewBox.left())
-    dy = sy*(pinPoint.y()-viewBox.top())
+    dx = sx * (pinPoint.x() - viewBox.left())
+    dy = sy * (pinPoint.y() - viewBox.top())
     for pos in points:
-        x = pos.x()-dx
-        y = pos.y()-dy
+        x = pos.x() - dx
+        y = pos.y() - dy
         renderer.render(painter, QRectF(x, y, sz.width(), sz.height()))
 
 
@@ -101,12 +108,12 @@ def qwtDrawGraphicSymbols(painter, points, numPoint, graphic, symbol):
     pointRect = QRectF(graphic.controlPointRect())
     if pointRect.isEmpty():
         return
-    sx = 1.
-    sy = 1.
+    sx = 1.0
+    sy = 1.0
     sz = symbol.size()
     if sz.isValid():
-        sx = sz.width()/pointRect.width()
-        sy = sz.height()/pointRect.height()
+        sx = sz.width() / pointRect.width()
+        sy = sz.height() / pointRect.height()
     pinPoint = QPointF(pointRect.center())
     if symbol.isPinPointEnabled():
         pinPoint = symbol.pinPoint()
@@ -124,15 +131,15 @@ def qwtDrawGraphicSymbols(painter, points, numPoint, graphic, symbol):
 def qwtDrawEllipseSymbols(painter, points, numPoints, symbol):
     painter.setBrush(symbol.brush())
     painter.setPen(symbol.pen())
-    size =symbol.size()
+    size = symbol.size()
     sw = size.width()
     sh = size.height()
-    sw2 = .5*size.width()
-    sh2 = .5*size.height()
+    sw2 = 0.5 * size.width()
+    sh2 = 0.5 * size.height()
     for pos in points:
         x = pos.x()
         y = pos.y()
-        r = QRectF(x-sw2, y-sh2, sw, sh)
+        r = QRectF(x - sw2, y - sh2, sw, sh)
         painter.drawEllipse(r)
 
 
@@ -145,26 +152,26 @@ def qwtDrawRectSymbols(painter, points, numPoints, symbol):
     painter.setRenderHint(QPainter.Antialiasing, False)
     sw = size.width()
     sh = size.height()
-    sw2 = .5*size.width()
-    sh2 = .5*size.height()
+    sw2 = 0.5 * size.width()
+    sh2 = 0.5 * size.height()
     for pos in points:
         x = pos.x()
         y = pos.y()
-        r = QRectF(x-sw2, y-sh2, sw, sh)
+        r = QRectF(x - sw2, y - sh2, sw, sh)
         painter.drawRect(r)
 
 
 def qwtDrawDiamondSymbols(painter, points, numPoints, symbol):
-    size =symbol.size()
+    size = symbol.size()
     pen = QPen(symbol.pen())
     pen.setJoinStyle(Qt.MiterJoin)
     painter.setPen(pen)
     painter.setBrush(symbol.brush())
     for pos in points:
-        x1 = pos.x()-.5*size.width()
-        y1 = pos.y()-.5*size.height()
-        x2 = x1+size.width()
-        y2 = y1+size.height()
+        x1 = pos.x() - 0.5 * size.width()
+        y1 = pos.y() - 0.5 * size.height()
+        x2 = x1 + size.width()
+        y2 = y1 + size.height()
         polygon = QPolygonF()
         polygon += QPointF(pos.x(), y1)
         polygon += QPointF(x1, pos.y())
@@ -174,20 +181,20 @@ def qwtDrawDiamondSymbols(painter, points, numPoints, symbol):
 
 
 def qwtDrawTriangleSymbols(painter, type, points, numPoint, symbol):
-    size =symbol.size()
+    size = symbol.size()
     pen = QPen(symbol.pen())
     pen.setJoinStyle(Qt.MiterJoin)
     painter.setPen(pen)
     painter.setBrush(symbol.brush())
-    sw2 = .5*size.width()
-    sh2 = .5*size.height()
+    sw2 = 0.5 * size.width()
+    sh2 = 0.5 * size.height()
     for pos in points:
         x = pos.x()
         y = pos.y()
-        x1 = x-sw2
-        x2 = x1+size.width()
-        y1 = y-sh2
-        y2 = y1+size.height()
+        x1 = x - sw2
+        x2 = x1 + size.width()
+        y1 = y - sh2
+        y2 = y1 + size.height()
         if type == QwtTriangle.Left:
             triangle = [QPointF(x2, y1), QPointF(x1, y), QPointF(x2, y2)]
         elif type == QwtTriangle.Right:
@@ -196,11 +203,13 @@ def qwtDrawTriangleSymbols(painter, type, points, numPoint, symbol):
             triangle = [QPointF(x1, y2), QPointF(x, y1), QPointF(x2, y2)]
         elif type == QwtTriangle.Down:
             triangle = [QPointF(x1, y1), QPointF(x, y2), QPointF(x2, y1)]
+        else:
+            raise TypeError("Unknown triangle type %s" % type)
         painter.drawPolygon(QPolygonF(triangle))
 
 
 def qwtDrawLineSymbols(painter, orientations, points, numPoints, symbol):
-    size =symbol.size()
+    size = symbol.size()
     pen = QPen(symbol.pen())
     if pen.width() > 1:
         pen.setCapStyle(Qt.FlatCap)
@@ -208,49 +217,49 @@ def qwtDrawLineSymbols(painter, orientations, points, numPoints, symbol):
     painter.setRenderHint(QPainter.Antialiasing, False)
     sw = size.width()
     sh = size.height()
-    sw2 = .5*size.width()
-    sh2 = .5*size.height()
+    sw2 = 0.5 * size.width()
+    sh2 = 0.5 * size.height()
     for pos in points:
         if orientations & Qt.Horizontal:
-            x = round(pos.x())-sw2
+            x = round(pos.x()) - sw2
             y = round(pos.y())
-            painter.drawLine(x, y, x+sw, y)
+            painter.drawLine(x, y, x + sw, y)
         if orientations & Qt.Vertical:
             x = round(pos.x())
-            y = round(pos.y())-sh2
-            painter.drawLine(x, y, x, y+sh)
+            y = round(pos.y()) - sh2
+            painter.drawLine(x, y, x, y + sh)
 
 
 def qwtDrawXCrossSymbols(painter, points, numPoints, symbol):
-    size =symbol.size()
+    size = symbol.size()
     pen = QPen(symbol.pen())
     if pen.width() > 1:
         pen.setCapStyle(Qt.FlatCap)
     painter.setPen(pen)
     sw = size.width()
     sh = size.height()
-    sw2 = .5*size.width()
-    sh2 = .5*size.height()
+    sw2 = 0.5 * size.width()
+    sh2 = 0.5 * size.height()
     for pos in points:
-        x1 = pos.x()-sw2
-        x2 = x1+sw
-        y1 = pos.y()-sh2
-        y2 = y1+sh
+        x1 = pos.x() - sw2
+        x2 = x1 + sw
+        y1 = pos.y() - sh2
+        y2 = y1 + sh
         painter.drawLine(x1, y1, x2, y2)
         painter.drawLine(x2, y1, x1, y2)
 
 
 def qwtDrawStar1Symbols(painter, points, numPoints, symbol):
-    size =symbol.size()
+    size = symbol.size()
     painter.setPen(symbol.pen())
-    sqrt1_2 = np.sqrt(.5)
+    sqrt1_2 = np.sqrt(0.5)
     r = QRectF(0, 0, size.width(), size.height())
     for pos in points:
         r.moveCenter(pos.toPoint())
         c = QPointF(r.center())
-        d1 = r.width()/2.*(1.-sqrt1_2)
-        painter.drawLine(r.left()+d1, r.top()+d1, r.right()-d1, r.bottom()-d1)
-        painter.drawLine(r.left()+d1, r.bottom()-d1, r.right()-d1, r.top()+d1)
+        d1 = r.width() / 2.0 * (1.0 - sqrt1_2)
+        painter.drawLine(r.left() + d1, r.top() + d1, r.right() - d1, r.bottom() - d1)
+        painter.drawLine(r.left() + d1, r.bottom() - d1, r.right() - d1, r.top() + d1)
         painter.drawLine(c.x(), r.top(), c.x(), r.bottom())
         painter.drawLine(r.left(), c.y(), r.right(), c.y())
 
@@ -262,54 +271,70 @@ def qwtDrawStar2Symbols(painter, points, numPoints, symbol):
     pen.setJoinStyle(Qt.MiterJoin)
     painter.setPen(pen)
     painter.setBrush(symbol.brush())
-    cos30 = np.cos(30*np.pi/180.)
-    dy = .25*symbol.size().height()
-    dx = .5*symbol.size().width()*cos30/3.
+    cos30 = np.cos(30 * np.pi / 180.0)
+    dy = 0.25 * symbol.size().height()
+    dx = 0.5 * symbol.size().width() * cos30 / 3.0
     for pos in points:
         x = pos.x()
         y = pos.y()
-        x1 = x-3*dx
-        y1 = y-2*dy
-        x2 = x1+1*dx
-        x3 = x1+2*dx
-        x4 = x1+3*dx
-        x5 = x1+4*dx
-        x6 = x1+5*dx
-        x7 = x1+6*dx
-        y2 = y1+1*dy
-        y3 = y1+2*dy
-        y4 = y1+3*dy
-        y5 = y1+4*dy
-        star = [QPointF(x4, y1), QPointF(x5, y2), QPointF(x7, y2),
-                QPointF(x6, y3), QPointF(x7, y4), QPointF(x5, y4),
-                QPointF(x4, y5), QPointF(x3, y4), QPointF(x1, y4),
-                QPointF(x2, y3), QPointF(x1, y2), QPointF(x3, y2)]
+        x1 = x - 3 * dx
+        y1 = y - 2 * dy
+        x2 = x1 + 1 * dx
+        x3 = x1 + 2 * dx
+        x4 = x1 + 3 * dx
+        x5 = x1 + 4 * dx
+        x6 = x1 + 5 * dx
+        x7 = x1 + 6 * dx
+        y2 = y1 + 1 * dy
+        y3 = y1 + 2 * dy
+        y4 = y1 + 3 * dy
+        y5 = y1 + 4 * dy
+        star = [
+            QPointF(x4, y1),
+            QPointF(x5, y2),
+            QPointF(x7, y2),
+            QPointF(x6, y3),
+            QPointF(x7, y4),
+            QPointF(x5, y4),
+            QPointF(x4, y5),
+            QPointF(x3, y4),
+            QPointF(x1, y4),
+            QPointF(x2, y3),
+            QPointF(x1, y2),
+            QPointF(x3, y2),
+        ]
         painter.drawPolygon(QPolygonF(star))
 
 
 def qwtDrawHexagonSymbols(painter, points, numPoints, symbol):
     painter.setBrush(symbol.brush())
     painter.setPen(symbol.pen())
-    cos30 = np.cos(30*np.pi/180.)
-    dx = .5*(symbol.size().width()-cos30)
-    dy = .25*symbol.size().height()
+    cos30 = np.cos(30 * np.pi / 180.0)
+    dx = 0.5 * (symbol.size().width() - cos30)
+    dy = 0.25 * symbol.size().height()
     for pos in points:
         x = pos.x()
         y = pos.y()
-        x1 = x-dx
-        y1 = y-2*dy
-        x2 = x1+1*dx
-        x3 = x1+2*dx
-        y2 = y1+1*dy
-        y3 = y1+3*dy
-        y4 = y1+4*dy
-        hexa = [QPointF(x2, y1), QPointF(x3, y2), QPointF(x3, y3),
-                QPointF(x2, y4), QPointF(x1, y3), QPointF(x1, y2)]
+        x1 = x - dx
+        y1 = y - 2 * dy
+        x2 = x1 + 1 * dx
+        x3 = x1 + 2 * dx
+        y2 = y1 + 1 * dy
+        y3 = y1 + 3 * dy
+        y4 = y1 + 4 * dy
+        hexa = [
+            QPointF(x2, y1),
+            QPointF(x3, y2),
+            QPointF(x3, y3),
+            QPointF(x2, y4),
+            QPointF(x1, y3),
+            QPointF(x1, y2),
+        ]
         painter.drawPolygon(QPolygonF(hexa))
 
 
 class QwtSymbol_PrivateData(object):
-    def __init__(self, st, br, pn ,sz):
+    def __init__(self, st, br, pn, sz):
         self.style = st
         self.size = sz
         self.brush = br
@@ -321,27 +346,32 @@ class QwtSymbol_PrivateData(object):
             def __init__(self):
                 self.path = QPainterPath()
                 self.graphic = QwtGraphic()
+
         self.path = Path()
-        
+
         class Pixmap(object):
             def __init__(self):
                 self.pixmap = QPixmap()
-        self.pixmap = None  #Pixmap()
-        
+
+        self.pixmap = None  # Pixmap()
+
         class Graphic(object):
             def __init__(self):
                 self.graphic = QwtGraphic()
+
         self.graphic = Graphic()
-        
+
         class SVG(object):
             def __init__(self):
                 self.renderer = QSvgRenderer()
+
         self.svg = SVG()
-        
+
         class PaintCache(object):
             def __init__(self):
                 self.policy = 0
-                self.pixmap = None  #QPixmap()
+                self.pixmap = None  # QPixmap()
+
         self.cache = PaintCache()
 
 
@@ -456,37 +486,108 @@ class QwtSymbol(object):
         :py:meth:`setPath()`, :py:meth:`setBrush()`, 
         :py:meth:`setPen()`, :py:meth:`setSize()`
     """
-    
+
     # enum Style
     Style = int
     NoSymbol = -1
-    (Ellipse, Rect, Diamond, Triangle, DTriangle, UTriangle, LTriangle,
-     RTriangle, Cross, XCross, HLine, VLine, Star1, Star2, Hexagon, Path,
-     Pixmap, Graphic, SvgDocument) = list(range(19))
+    (
+        Ellipse,
+        Rect,
+        Diamond,
+        Triangle,
+        DTriangle,
+        UTriangle,
+        LTriangle,
+        RTriangle,
+        Cross,
+        XCross,
+        HLine,
+        VLine,
+        Star1,
+        Star2,
+        Hexagon,
+        Path,
+        Pixmap,
+        Graphic,
+        SvgDocument,
+    ) = list(range(19))
     UserStyle = 1000
-    
+
     # enum CachePolicy
     NoCache, Cache, AutoCache = list(range(3))
-    
+
     def __init__(self, *args):
         if len(args) in (0, 1):
             if args:
-                style, = args
+                (style,) = args
             else:
                 style = QwtSymbol.NoSymbol
-            self.__data = QwtSymbol_PrivateData(style, QBrush(Qt.gray),
-                                                QPen(Qt.black, 0), QSize())
+            self.__data = QwtSymbol_PrivateData(
+                style, QBrush(Qt.gray), QPen(Qt.black, 0), QSize()
+            )
         elif len(args) == 4:
             style, brush, pen, size = args
             self.__data = QwtSymbol_PrivateData(style, brush, pen, size)
         elif len(args) == 3:
             path, brush, pen = args
-            self.__data = QwtSymbol_PrivateData(QwtSymbol.Path, brush, pen,
-                                                QSize())
+            self.__data = QwtSymbol_PrivateData(QwtSymbol.Path, brush, pen, QSize())
             self.setPath(path)
         else:
-            raise TypeError("%s() takes 1, 3, or 4 argument(s) (%s given)"\
-                            % (self.__class__.__name__, len(args)))
+            raise TypeError(
+                "%s() takes 1, 3, or 4 argument(s) (%s given)"
+                % (self.__class__.__name__, len(args))
+            )
+
+    @classmethod
+    def make(
+        cls, style=None, brush=None, pen=None, size=None, path=None, pixmap=None, graphic=None, svgdocument=None, pinpoint=None,
+    ):
+        """
+        Create and setup a new `QwtSymbol` object (convenience function).
+        
+        :param style: Symbol Style
+        :type style: int or None
+        :param brush: Brush to fill the interior
+        :type brush: QBrush or None
+        :param pen: Outline pen
+        :type pen: QPen or None
+        :param size: Size
+        :type size: QSize or None
+        :param path: Painter path
+        :type path: QPainterPath or None
+        :param path: Painter path
+        :type path: QPainterPath or None
+        :param pixmap: Pixmap as symbol
+        :type pixmap: QPixmap or None
+        :param graphic: Graphic
+        :type graphic: qwt.graphic.QwtGraphic or None
+        :param svgdocument: SVG icon as symbol
+
+        .. seealso::
+        
+            :py:meth:`setPixmap()`, :py:meth:`setGraphic()`, :py:meth:`setPath()`
+        """
+        style = QwtSymbol.NoSymbol if style is None else style
+        brush = QBrush(Qt.gray) if brush is None else QBrush(brush)
+        pen = QPen(Qt.black, 0) if pen is None else QPen(pen)
+        size = QSize() if size is None else size
+        if not isinstance(size, QSize):
+            if isinstance(size, tuple) and len(size) == 2:
+                size = QSize(size[0], size[1])
+            else:
+                raise TypeError("Invalid size %r" % size)
+        item = cls(style, brush, pen, size)
+        if path is not None:
+            item.setPath(path)
+        elif pixmap is not None:
+            item.setPixmap(pixmap)
+        elif graphic is not None:
+            item.setGraphic(graphic)
+        elif svgdocument is not None:
+            item.setSvgDocument(svgdocument)
+        if pinpoint is not None:
+            item.setPinPoint(pinpoint)
+        return item
 
     def setCachePolicy(self, policy):
         """
@@ -503,7 +604,7 @@ class QwtSymbol(object):
         if self.__data.cache.policy != policy:
             self.__data.cache.policy = policy
             self.invalidateCache()
-    
+
     def cachePolicy(self):
         """
         :return: Cache policy
@@ -513,7 +614,7 @@ class QwtSymbol(object):
             :py:meth:`setCachePolicy()`
         """
         return self.__data.cache.policy
-    
+
     def setPath(self, path):
         """
         Set a painter path as symbol
@@ -588,7 +689,7 @@ class QwtSymbol(object):
         self.__data.style = QwtSymbol.Path
         self.__data.path.path = path
         self.__data.path.graphic.reset()
-    
+
     def path(self):
         """
         :return: Painter path for displaying the symbol
@@ -598,7 +699,7 @@ class QwtSymbol(object):
             :py:meth:`setPath()`
         """
         return self.__data.path.path
-    
+
     def setPixmap(self, pixmap):
         """
         Set a pixmap as symbol
@@ -619,7 +720,7 @@ class QwtSymbol(object):
         """
         self.__data.style = QwtSymbol.Pixmap
         self.__data.pixmap.pixmap = pixmap
-    
+
     def pixmap(self):
         """
         :return: Assigned pixmap
@@ -629,7 +730,7 @@ class QwtSymbol(object):
             :py:meth:`setPixmap()`
         """
         return self.__data.pixmap.pixmap
-    
+
     def setGraphic(self, graphic):
         """
         Set a graphic as symbol
@@ -650,7 +751,7 @@ class QwtSymbol(object):
         """
         self.__data.style = QwtSymbol.Graphic
         self.__data.graphic.graphic = graphic
-    
+
     def graphic(self):
         """
         :return: Assigned graphic
@@ -660,7 +761,7 @@ class QwtSymbol(object):
             :py:meth:`setGraphic()`
         """
         return self.__data.graphic.graphic
-    
+
     def setSvgDocument(self, svgDocument):
         """
         Set a SVG icon as symbol
@@ -683,7 +784,7 @@ class QwtSymbol(object):
         if self.__data.svg.renderer is None:
             self.__data.svg.renderer = QSvgRenderer()
         self.__data.svg.renderer.load(svgDocument)
-    
+
     def setSize(self, *args):
         """
         Specify the symbol's size
@@ -708,17 +809,19 @@ class QwtSymbol(object):
             self.setSize(QSize(width, height))
         elif len(args) == 1:
             if isinstance(args[0], QSize):
-                size, = args
+                (size,) = args
                 if size.isValid() and size != self.__data.size:
                     self.__data.size = size
                     self.invalidateCache()
             else:
-                width, = args
+                (width,) = args
                 self.setSize(width, -1)
         else:
-            raise TypeError("%s().setSize() takes 1 or 2 argument(s) (%s given)"\
-                            % (self.__class__.__name__, len(args)))
-    
+            raise TypeError(
+                "%s().setSize() takes 1 or 2 argument(s) (%s given)"
+                % (self.__class__.__name__, len(args))
+            )
+
     def size(self):
         """
         :return: Size
@@ -728,7 +831,7 @@ class QwtSymbol(object):
             :py:meth:`setSize()`
         """
         return self.__data.size
-    
+
     def setBrush(self, brush):
         """
         Assign a brush
@@ -746,7 +849,7 @@ class QwtSymbol(object):
             self.invalidateCache()
             if self.__data.style == QwtSymbol.Path:
                 self.__data.path.graphic.reset()
-    
+
     def brush(self):
         """
         :return: Brush
@@ -756,7 +859,7 @@ class QwtSymbol(object):
             :py:meth:`setBrush()`
         """
         return self.__data.brush
-    
+
     def setPen(self, *args):
         """
         Build and/or assign a pen, depending on the arguments.
@@ -787,15 +890,17 @@ class QwtSymbol(object):
             color, width, style = args
             self.setPen(QPen(color, width, style))
         elif len(args) == 1:
-            pen, = args
+            (pen,) = args
             if pen != self.__data.pen:
                 self.__data.pen = pen
                 self.invalidateCache()
                 if self.__data.style == QwtSymbol.Path:
                     self.__data.path.graphic.reset()
         else:
-            raise TypeError("%s().setPen() takes 1 or 3 argument(s) (%s given)"\
-                            % (self.__class__.__name__, len(args)))
+            raise TypeError(
+                "%s().setPen() takes 1 or 3 argument(s) (%s given)"
+                % (self.__class__.__name__, len(args))
+            )
 
     def pen(self):
         """
@@ -806,7 +911,7 @@ class QwtSymbol(object):
             :py:meth:`setPen()`, :py:meth:`brush()`
         """
         return self.__data.pen
-    
+
     def setColor(self, color):
         """
         Set the color of the symbol
@@ -821,27 +926,37 @@ class QwtSymbol(object):
             :py:meth:`setPen()`, :py:meth:`setBrush()`, 
             :py:meth:`brush()`, :py:meth:`pen()`
         """
-        if self.__data.style in (QwtSymbol.Ellipse, QwtSymbol.Rect,
-                                 QwtSymbol.Diamond, QwtSymbol.Triangle,
-                                 QwtSymbol.UTriangle, QwtSymbol.DTriangle,
-                                 QwtSymbol.RTriangle, QwtSymbol.LTriangle,
-                                 QwtSymbol.Star2, QwtSymbol.Hexagon):
+        if self.__data.style in (
+            QwtSymbol.Ellipse,
+            QwtSymbol.Rect,
+            QwtSymbol.Diamond,
+            QwtSymbol.Triangle,
+            QwtSymbol.UTriangle,
+            QwtSymbol.DTriangle,
+            QwtSymbol.RTriangle,
+            QwtSymbol.LTriangle,
+            QwtSymbol.Star2,
+            QwtSymbol.Hexagon,
+        ):
             if self.__data.brush.color() != color:
                 self.__data.brush.setColor(color)
                 self.invalidateCache()
-        elif self.__data.style in (QwtSymbol.Cross, QwtSymbol.XCross,
-                                   QwtSymbol.HLine, QwtSymbol.VLine,
-                                   QwtSymbol.Star1):
+        elif self.__data.style in (
+            QwtSymbol.Cross,
+            QwtSymbol.XCross,
+            QwtSymbol.HLine,
+            QwtSymbol.VLine,
+            QwtSymbol.Star1,
+        ):
             if self.__data.pen.color() != color:
                 self.__data.pen.setColor(color)
                 self.invalidateCache()
         else:
-            if self.__data.brush.color() != color or\
-               self.__data.pen.color() != color:
+            if self.__data.brush.color() != color or self.__data.pen.color() != color:
                 self.invalidateCache()
             self.__data.brush.setColor(color)
             self.__data.pen.setColor(color)
-    
+
     def setPinPoint(self, pos, enable=True):
         """
         Set and enable a pin point
@@ -864,7 +979,7 @@ class QwtSymbol(object):
             if self.__data.isPinPointEnabled:
                 self.invalidateCache()
         self.setPinPointEnabled(enable)
-    
+
     def pinPoint(self):
         """
         :return: Pin point
@@ -874,7 +989,7 @@ class QwtSymbol(object):
             :py:meth:`setPinPoint()`, :py:meth:`setPinPointEnabled()`
         """
         return self.__data.pinPoint
-    
+
     def setPinPointEnabled(self, on):
         """
         En/Disable the pin point alignment
@@ -888,7 +1003,7 @@ class QwtSymbol(object):
         if self.__data.isPinPointEnabled != on:
             self.__data.isPinPointEnabled = on
             self.invalidateCache()
-    
+
     def isPinPointEnabled(self):
         """
         :return: True, when the pin point translation is enabled
@@ -898,7 +1013,7 @@ class QwtSymbol(object):
             :py:meth:`setPinPoint()`, :py:meth:`setPinPointEnabled()`
         """
         return self.__data.isPinPointEnabled
-    
+
     def drawSymbols(self, painter, points, numPoints=None):
         """
         Render an array of symbols
@@ -910,13 +1025,13 @@ class QwtSymbol(object):
         :param QPainter painter: Painter
         :param QPolygonF points: Positions of the symbols in screen coordinates
         """
-        #TODO: remove argument numPoints (not necessary in `PythonQwt`)
+        # TODO: remove argument numPoints (not necessary in `PythonQwt`)
         if numPoints is not None and numPoints <= 0:
             return
         painter.save()
         self.renderSymbols(painter, points, numPoints)
         painter.restore()
-    
+
     def drawSymbol(self, painter, point_or_rect):
         """
         Draw the symbol into a rectangle
@@ -940,12 +1055,12 @@ class QwtSymbol(object):
         if self.__data.style == QwtSymbol.NoSymbol:
             return
         if self.__data.style == QwtSymbol.Graphic:
-            self.__data.graphic.graphic.render(painter, rect,
-                                               Qt.KeepAspectRatio)
+            self.__data.graphic.graphic.render(painter, rect, Qt.KeepAspectRatio)
         elif self.__data.style == QwtSymbol.Path:
             if self.__data.path.graphic.isNull():
                 self.__data.path.graphic = qwtPathGraphic(
-                    self.__data.path.path, self.__data.pen, self.__data.brush)
+                    self.__data.path.path, self.__data.pen, self.__data.brush
+                )
             self.__data.path.graphic.render(painter, rect, Qt.KeepAspectRatio)
             return
         elif self.__data.style == QwtSymbol.SvgDocument:
@@ -961,7 +1076,7 @@ class QwtSymbol(object):
                 self.__data.svg.renderer.render(painter, scaledRect)
         else:
             br = QRect(self.boundingRect())
-            ratio = min([rect.width()/br.width(), rect.height()/br.height()])
+            ratio = min([rect.width() / br.width(), rect.height() / br.height()])
             painter.save()
             painter.translate(rect.center())
             painter.scale(ratio, ratio)
@@ -971,7 +1086,7 @@ class QwtSymbol(object):
             self.renderSymbols(painter, pos, 1)
             self.__data.isPinPointEnabled = isPinPointEnabled
             painter.restore()
-    
+
     def renderSymbols(self, painter, points, numPoints=None):
         """
         Render the symbol to series of points
@@ -979,12 +1094,13 @@ class QwtSymbol(object):
         :param QPainter painter: Painter
         :param point_or_rect: Positions of the symbols
         """
-        #TODO: remove argument numPoints (not necessary in `PythonQwt`)
+        # TODO: remove argument numPoints (not necessary in `PythonQwt`)
         try:
             assert numPoints is None
         except AssertionError:
-            raise RuntimeError("argument numPoints is not implemented "\
-                               "in `PythonQwt`")
+            raise RuntimeError(
+                "argument numPoints is not implemented " "in `PythonQwt`"
+            )
         if self.__data.style == QwtSymbol.Ellipse:
             qwtDrawEllipseSymbols(painter, points, numPoints, self)
         elif self.__data.style == QwtSymbol.Rect:
@@ -992,22 +1108,19 @@ class QwtSymbol(object):
         elif self.__data.style == QwtSymbol.Diamond:
             qwtDrawDiamondSymbols(painter, points, numPoints, self)
         elif self.__data.style == QwtSymbol.Cross:
-            qwtDrawLineSymbols(painter, Qt.Horizontal|Qt.Vertical,
-                               points, numPoints, self)
+            qwtDrawLineSymbols(
+                painter, Qt.Horizontal | Qt.Vertical, points, numPoints, self
+            )
         elif self.__data.style == QwtSymbol.XCross:
             qwtDrawXCrossSymbols(painter, points, numPoints, self)
         elif self.__data.style in (QwtSymbol.Triangle, QwtSymbol.UTriangle):
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Up,
-                                   points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Up, points, numPoints, self)
         elif self.__data.style == QwtSymbol.DTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Down,
-                                   points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Down, points, numPoints, self)
         elif self.__data.style == QwtSymbol.RTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Right,
-                                   points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Right, points, numPoints, self)
         elif self.__data.style == QwtSymbol.LTriangle:
-            qwtDrawTriangleSymbols(painter, QwtTriangle.Left,
-                                   points, numPoints, self)
+            qwtDrawTriangleSymbols(painter, QwtTriangle.Left, points, numPoints, self)
         elif self.__data.style == QwtSymbol.HLine:
             qwtDrawLineSymbols(painter, Qt.Horizontal, points, numPoints, self)
         elif self.__data.style == QwtSymbol.VLine:
@@ -1021,17 +1134,21 @@ class QwtSymbol(object):
         elif self.__data.style == QwtSymbol.Path:
             if self.__data.path.graphic.isNull():
                 self.__data.path.graphic = qwtPathGraphic(
-                    self.__data.path.path, self.__data.pen, self.__data.brush)
-            qwtDrawGraphicSymbols(painter, points, numPoints,
-                                  self.__data.path.graphic, self)
+                    self.__data.path.path, self.__data.pen, self.__data.brush
+                )
+            qwtDrawGraphicSymbols(
+                painter, points, numPoints, self.__data.path.graphic, self
+            )
         elif self.__data.style == QwtSymbol.Pixmap:
             qwtDrawPixmapSymbols(painter, points, numPoints, self)
         elif self.__data.style == QwtSymbol.Graphic:
-            qwtDrawGraphicSymbols(painter, points, numPoints,
-                                  self.__data.graphic.graphic, self)
+            qwtDrawGraphicSymbols(
+                painter, points, numPoints, self.__data.graphic.graphic, self
+            )
         elif self.__data.style == QwtSymbol.SvgDocument:
-            qwtDrawSvgSymbols(painter, points, numPoints,
-                              self.__data.svg.renderer, self)
+            qwtDrawSvgSymbols(
+                painter, points, numPoints, self.__data.svg.renderer, self
+            )
 
     def boundingRect(self):
         """
@@ -1041,29 +1158,34 @@ class QwtSymbol(object):
         """
         rect = QRectF()
         pinPointTranslation = False
-        if self.__data.style in (QwtSymbol.Ellipse, QwtSymbol.Rect,
-                                 QwtSymbol.Hexagon):
-            pw = 0.
+        if self.__data.style in (QwtSymbol.Ellipse, QwtSymbol.Rect, QwtSymbol.Hexagon):
+            pw = 0.0
             if self.__data.pen.style() != Qt.NoPen:
-                pw = max([self.__data.pen.widthF(), 1.])
-            rect.setSize(self.__data.size+QSizeF(pw, pw))
-            rect.moveCenter(QPointF(0., 0.))
-        elif self.__data.style in (QwtSymbol.XCross, QwtSymbol.Diamond,
-                                   QwtSymbol.Triangle, QwtSymbol.UTriangle,
-                                   QwtSymbol.DTriangle, QwtSymbol.RTriangle,
-                                   QwtSymbol.LTriangle, QwtSymbol.Star1,
-                                   QwtSymbol.Star2):
-            pw = 0.
+                pw = max([self.__data.pen.widthF(), 1.0])
+            rect.setSize(self.__data.size + QSizeF(pw, pw))
+            rect.moveCenter(QPointF(0.0, 0.0))
+        elif self.__data.style in (
+            QwtSymbol.XCross,
+            QwtSymbol.Diamond,
+            QwtSymbol.Triangle,
+            QwtSymbol.UTriangle,
+            QwtSymbol.DTriangle,
+            QwtSymbol.RTriangle,
+            QwtSymbol.LTriangle,
+            QwtSymbol.Star1,
+            QwtSymbol.Star2,
+        ):
+            pw = 0.0
             if self.__data.pen.style() != Qt.NoPen:
-                pw = max([self.__data.pen.widthF(), 1.])
-            rect.setSize(QSizeF(self.__data.size)+QSizeF(2*pw, 2*pw))
-            rect.moveCenter(QPointF(0., 0.))
+                pw = max([self.__data.pen.widthF(), 1.0])
+            rect.setSize(QSizeF(self.__data.size) + QSizeF(2 * pw, 2 * pw))
+            rect.moveCenter(QPointF(0.0, 0.0))
         elif self.__data.style == QwtSymbol.Path:
             if self.__data.path.graphic.isNull():
                 self.__data.path.graphic = qwtPathGraphic(
-                    self.__data.path.path, self.__data.pen, self.__data.brush)
-            rect = qwtScaleBoundingRect(self.__data.path.graphic,
-                                        self.__data.size)
+                    self.__data.path.path, self.__data.pen, self.__data.brush
+                )
+            rect = qwtScaleBoundingRect(self.__data.path.graphic, self.__data.size)
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.Pixmap:
             if self.__data.size.isEmpty():
@@ -1072,27 +1194,26 @@ class QwtSymbol(object):
                 rect.setSize(self.__data.size)
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.Graphic:
-            rect = qwtScaleBoundingRect(self.__data.graphic.graphic,
-                                        self.__data.size)
+            rect = qwtScaleBoundingRect(self.__data.graphic.graphic, self.__data.size)
             pinPointTranslation = True
         elif self.__data.style == QwtSymbol.SvgDocument:
             if self.__data.svg.renderer is not None:
                 rect = self.__data.svg.renderer.viewBoxF()
             if self.__data.size.isValid() and not rect.isEmpty():
                 sz = QSizeF(rect.size())
-                sx = self.__data.size.width()/sz.width()
-                sy = self.__data.size.height()/sz.height()
+                sx = self.__data.size.width() / sz.width()
+                sy = self.__data.size.height() / sz.height()
                 transform = QTransform()
                 transform.scale(sx, sy)
                 rect = transform.mapRect(rect)
             pinPointTranslation = True
         else:
             rect.setSize(self.__data.size)
-            rect.moveCenter(QPointF(0., 0.))
+            rect.moveCenter(QPointF(0.0, 0.0))
         if pinPointTranslation:
-            pinPoint = QPointF(0., 0.)
+            pinPoint = QPointF(0.0, 0.0)
             if self.__data.isPinPointEnabled:
-                pinPoint = rect.center()-self.__data.pinPoint
+                pinPoint = rect.center() - self.__data.pinPoint
             rect.moveCenter(pinPoint)
         r = QRect()
         r.setLeft(np.floor(rect.left()))
@@ -1102,7 +1223,7 @@ class QwtSymbol(object):
         if self.__data.style != QwtSymbol.Pixmap:
             r.adjust(-1, -1, 1, 1)
         return r
-    
+
     def invalidateCache(self):
         """
         Invalidate the cached symbol pixmap
@@ -1119,7 +1240,7 @@ class QwtSymbol(object):
         """
         if self.__data.cache.pixmap is not None:
             self.__data.cache.pixmap = QPixmap()
-    
+
     def setStyle(self, style):
         """
         Specify the symbol style
@@ -1133,7 +1254,7 @@ class QwtSymbol(object):
         if self.__data.style != style:
             self.__data.style = style
             self.invalidateCache()
-    
+
     def style(self):
         """
         :return: Current symbol style
